==> azure-data-lake-store-python_0.0.53.orig.tar.gz: azure-data-lake-store-python-0.0.53/setup.py <==
#!/usr/bin/env python

from setuptools import find_packages, setup
from io import open
import re

with open('README.rst', encoding='utf-8') as f:
    readme = f.read()
with open('HISTORY.rst', encoding='utf-8') as f:
    history = f.read()

# Version extraction inspired from 'requests'
with open('azure/datalake/store/__init__.py', 'r') as fd:
    version = re.search(r'^__version__\s*=\s*[\'"]([^\'"]*)[\'"]',
                        fd.read(), re.MULTILINE).group(1)

if not version:
    raise RuntimeError('Cannot find version information')

setup(name='azure-datalake-store',
      version=version,
      description='Azure Data Lake Store Filesystem Client Library for Python',
      url='https://github.com/Azure/azure-data-lake-store-python',
      author='Microsoft Corporation',
      author_email='Akshat.Harit@microsoft.com',
      license='MIT License',
      keywords='azure',
      classifiers=[
          'Development Status :: 4 - Beta',
          'Programming Language :: Python',
          'Programming Language :: Python :: 2',
          'Programming Language :: Python :: 2.7',
          'Programming Language :: Python :: 3',
          'Programming Language :: Python :: 3.3',
          'Programming Language :: Python :: 3.4',
          'Programming Language :: Python :: 3.5',
          'Programming Language :: Python :: 3.6',
          'Programming Language :: Python :: 3.7',
          'Programming Language :: Python :: 3.8',
          'Programming Language :: Python :: 3.9',
          'Programming Language :: Python :: 3.10',
          'Programming Language :: Python :: 3.11',
          'License :: OSI Approved :: MIT License',
      ],
      packages=find_packages(exclude=['tests',
                                      # Exclude packages that will be covered by PEP420 or nspkg
                                      'azure',
                                      ]),
      install_requires=[
          'cffi',
          'msal>=1.16.0,<2',  # http_cache was introduced in MSAL 1.16.0
          'requests>=2.20.0',
      ],
      extras_require={
          ":python_version<'3.4'": ['pathlib2'],
          ":python_version<='2.7'": ['futures'],
          ":python_version<'3.0'": ['azure-nspkg'],
      },
      long_description=readme + '\n\n' + history,
      zip_safe=False,
)

==> azure-data-lake-store-python_1.0.1.orig.tar.gz: azure-data-lake-store-python-1.0.1/setup.py <==
#!/usr/bin/env python

from setuptools import find_packages, setup
from io import open
import re

with open('README.rst', encoding='utf-8') as f:
    readme = f.read()
with open('HISTORY.rst', encoding='utf-8') as f:
    history = f.read()

# Version extraction inspired from 'requests'
with open('azure/datalake/store/__init__.py', 'r') as fd:
    version = re.search(r'^__version__\s*=\s*[\'"]([^\'"]*)[\'"]',
                        fd.read(), re.MULTILINE).group(1)

if not version:
    raise RuntimeError('Cannot find version information')

setup(name='azure-datalake-store',
      version=version,
      description='Azure Data Lake Store Filesystem Client Library for Python',
      url='https://github.com/Azure/azure-data-lake-store-python',
      author='Microsoft Corporation',
      author_email='Akshat.Harit@microsoft.com',
      license='MIT License',
      keywords='azure',
      classifiers=[
          'Development Status :: 3 - Alpha',
          'Programming Language :: Python',
          'Programming Language :: Python :: 3',
          'Programming Language :: Python :: 3.9',
          'Programming Language :: Python :: 3.10',
          'Programming Language :: Python :: 3.11',
          'Programming Language :: Python :: 3.12',
          'License :: OSI Approved :: MIT License',
      ],
      packages=find_packages(exclude=['tests',
                                      # Exclude packages that will be covered by PEP420 or nspkg
                                      'azure',
                                      ]),
      install_requires=[
          'cffi',
          'requests>=2.20.0'
      ],
      extras_require={ 'auth': ['azure-identity']},
      long_description=readme + '\n\n' + history,
      long_description_content_type="text/x-rst",
      zip_safe=False,
)
